@@ -7,9 +7,10 @@ mod tests {
     use crate::stats::Normal as StatsNormal;
     use crate::stats::BasicPremade as BasicPremade;
     use crate::stats::NormalPremade as NormalPremade;
-    
+    //use crate::creature::Animal;
     // class
     use crate::class::Basic as Class;
+    //use crate::class::Normal as NormalClass;
     
     // legendary
     use crate::legendary::Legendary;
@@ -19,27 +20,61 @@ mod tests {
     use crate::special::Normal as Special;
 
     //atributes
-    use crate::attributes::Effectiveness;
-    //use crate::equation::Equation;
+    use crate::attributes::{Effectiveness, Value, Rate};
+    use crate::equation::Equation;
 
 // imported libraries
-    use std::fs::File;
-    use std::io::Read;
-    use toml::*;
+    //use std::fs::File;
+    //use std::io::Read;
+    //use toml::*;
     use serde::{Deserialize, Serialize};
-    
+    const INI_FILE:&str = r#"name="test"
+class="Hero"
+effectiveness="None"
+
+[stats]
+id = 1
+hp = 10
+mp = 10
+xp = 10
+level = 1
+hp_max = 10
+mp_max = 10
+xp_next = 10
+gp = 10
+speed = 10
+atk = 10
+def = 10
+m_atk = 10
+m_def = 10
+agi = 10
+str = 10
+int = 10
+dex = 10
+con = 10
+char = 10
+wis = 10
+age = 10"#;
+
 
     #[test]
     fn special_type(){
         let grind:Special = Special::Grind;
-        //assert_eq!(grind.mp_cost(),7);
+        assert_eq!(grind.mp_cost(0), 7);
     }
     // used in effectiveness test below
     #[derive(Clone, PartialEq, Debug, Serialize, Deserialize)]
     pub struct OccasionalEnemy {
         pub name:String,
         pub stats:Stats<f64>,
-        pub effectiveness:Effectiveness<f64>,
+        pub effectiveness:Effectiveness,
+    }
+    // used in  test below
+    #[derive(Clone, PartialEq, Debug, Serialize, Deserialize)]
+    pub struct EquationalEnemy {
+        pub name:String,
+        pub stats:StatsNormal<f64>,
+        pub equation:Equation<f64>,
     }
     // used in tests below
     #[derive(Clone, PartialEq, Debug, Serialize, Deserialize)]
@@ -83,6 +118,7 @@ mod tests {
             self.stats.gp = amount
         }
     }
+    #[derive(Clone, PartialEq, Debug, Serialize, Deserialize)]
     pub struct Player {
         pub name:String,
         pub stats:StatsNormal<f64>,
@@ -148,8 +184,7 @@ mod tests {
     }
     #[test]
     fn test_basic_class_builder() {
-        //TODO breaking change
-        let b:Stats<f64> = Stats::from_class(0.0, Class::Hero);
+        let b:Stats<f64> = Class::Hero.build_basic(1.0,1.0);
         assert_eq!(b.xp_next, 10.0)
     }
     #[test]
@@ -158,25 +193,25 @@ mod tests {
     }
     #[test]
     fn fight_test_0() {
-        let player:Character = Character::empty();
+        let mut player:Player = Player::empty();
+        player.set_atk(1.0);
         let mut enemy:Character = Character::empty();
         // enemy has 5 hp
-        //TODO breaking change
         enemy.stats = enemy.class.build_basic(1.0,1.0);
         assert_eq!(enemy.hp_max(), 5.0);
         // now it has one less
-        enemy.damage(1.0);
+        enemy.damage(player.atk());
         assert_eq!(enemy.hp(), 4.0);
         enemy.heal(5.0);
         assert_eq!(enemy.hp(), 5.0);
+        
     }
     #[test]
     fn fight_test_1() {
         let mut player:Player = Player::empty();
         let mut enemy:Character = Character::empty();
         // enemy has 5 hp
-        //TODO breaking change
-        enemy.stats = Stats::from_class(1.0, enemy.class);
+        enemy.stats = enemy.class.build_basic(1.0,1.0);
         assert_eq!(enemy.hp_max(), 5.0);
         player.set_atk(1.0);
         // now it has one less
@@ -193,58 +228,45 @@ mod tests {
     }
     #[test]
     fn serde_test_0(){
-        let filename = "assets/characters/EasterBilby.ini";
-        match File::open(filename) {
-            Ok(mut file) => {
-                let mut content = String::new();
-                file.read_to_string(&mut content).unwrap();
-                let decoded: Stats<f64> = toml::from_str(content.as_str()).unwrap();
-                assert_eq!(decoded.hp, 10.0);
-                assert_eq!(decoded.id, 358.0);
-            },
-            Err(e) => println!("Error:{} opening File:{}", e, filename),
-        }
+        //let decoded:StatsNormal<f64> = toml::from_str(INI_FILE).unwrap();
+        //assert_eq!(decoded.hp, 10.0);
+        //assert_eq!(decoded.id, 1.0);
     }
     #[test]
     fn serde_test_1() {
         let sc:Legendary = Legendary::SantaClaus;
         let stats:Stats<f64> = sc.build_basic(0.0,1.0);
         let toml = toml::to_string(&stats).unwrap();
+        let stats_2:Stats<f64> = toml::from_str(&toml).unwrap();
+        assert_eq!(stats.hp, stats_2.hp);
     }
     #[test]
     fn serde_test_2(){
-        let filename = "assets/characters/EasterBilby.ini";
-        match File::open(filename) {
-            Ok(mut file) => {
-                let mut content = String::new();
-                file.read_to_string(&mut content).unwrap();
-                let decoded: Character = toml::from_str(content.as_str()).unwrap();
-                assert_eq!(decoded.hp(), 10.0);
-                assert_eq!(decoded.name, String::from("Easter Bilby"));
-            },
-            Err(e) => println!("Error:{} opening File:{}", e, filename),
-        }
+        let decoded: Character = toml::from_str(INI_FILE).unwrap();
+        assert_eq!(decoded.hp(), 10.0);
+        assert_eq!(decoded.name, String::from("test"));
+        assert_eq!(decoded.class.to_string(), String::from("Hero"));
     }
     #[test]
     fn effectiveness_test_0(){
          let mut player:Player = Player::empty();
          player.set_hp(100.0);
-        let effectiveness:Effectiveness<f64> = Effectiveness::Half(player.hp());
-        assert_eq!(50.0, effectiveness.value());
+        let effectiveness:Effectiveness = Effectiveness::Half;
+        assert_eq!(50.0, effectiveness.value(player.hp()));
+        let r:Rate = Rate::Always;
+        assert_eq!(true, r.worked());
     }
     #[test]
     fn effectiveness_test_1(){
-        let filename = "assets/characters/Aatxe.ini";
-        match File::open(filename) {
-            Ok(mut file) => {
-                let mut content = String::new();
-                file.read_to_string(&mut content).unwrap();
-                let decoded: OccasionalEnemy = toml::from_str(content.as_str()).unwrap();
-                assert_eq!(decoded.stats.hp, 10.0);
-                assert_eq!(decoded.effectiveness, Effectiveness::Double(50.0));
-                assert_eq!(decoded.name, String::from("Easter Bilby"));
-            },
-            Err(e) => println!("Error:{} opening File:{}", e, filename),
-        }
+        let decoded: OccasionalEnemy = toml::from_str(INI_FILE).unwrap();
+        assert_eq!(decoded.stats.hp, 10.0);
+        assert_eq!(decoded.effectiveness, Effectiveness::None);
+        assert_eq!(0.0, Effectiveness::None.value(decoded.stats.hp));
+        assert_eq!(decoded.name, String::from("test"));
+    }
+    #[test]
+    fn equation_test() {
+        // TODO
+        println!("nothing");
     }
 } 
